@@ -103,12 +103,11 @@
 #define PETSC_HAVE_MPI_WIN_CREATE 1
 #define PETSC_HAVE_MUMPS 1
 #define PETSC_HAVE_NANOSLEEP 1
-#define PETSC_HAVE_NETCDF 1
 #define PETSC_HAVE_NETDB_H 1
 #define PETSC_HAVE_NETINET_IN_H 1
 #define PETSC_HAVE_NO_FINITE_MATH_ONLY 1
 #define PETSC_HAVE_OPENMPI 1
-#define PETSC_HAVE_PACKAGES ":amd:blaslapack:cholmod:fftw3:gsl:hdf5:hwloc:hypre:klu:libjpeg:mathlib:metis:mpi:mumps:netcdf:parmetis:pastix:pthread:ptscotch:regex:scalapack:spqr:superlu:superlu_dist:umfpack:yaml:zfp:zlib:"
+#define PETSC_HAVE_PACKAGES ":amd:blaslapack:cholmod:fftw3:gsl:hdf5:hwloc:hypre:klu:libjpeg:mathlib:metis:mpi:mumps:parmetis:pastix:pthread:ptscotch:regex:scalapack:spqr:superlu:superlu_dist:umfpack:yaml:zfp:"
 #define PETSC_HAVE_PARMETIS 1
 #define PETSC_HAVE_PASTIX 1
 #define PETSC_HAVE_PETSC4PY 1
@@ -178,7 +177,6 @@
 #define PETSC_LIB_NAME_SUFFIX ""
 #define PETSC_MAX_PATH_LEN 4096
 #define PETSC_MEMALIGN 16
-#define PETSC_MISSING_LAPACK_lsame 1
 #define PETSC_MPICC_SHOW "gcc -I/usr/include -Wl,-rpath -Wl,/usr/lib -Wl,--enable-new-dtags -lmpi"
 #define PETSC_MPIU_IS_COLORING_VALUE_TYPE MPI_UNSIGNED_SHORT
 #define PETSC_OMAKE "/usr/bin/make --no-print-directory"
